@@ -561,7 +561,8 @@ fetch_google_analytics_4_slow <- function(request_list,
     body <- rmNullObs(body)
     
     myMessage("Slow fetch: [", 
-              the_req$pageToken, "] from estimated actual Rows [", actualRows, "]", 
+              the_req$pageToken, "] from estimated actual Rows [", 
+              actualRows, "]", 
               level = 3)
 
     out <- tryCatch(f(the_body = body),
@@ -575,6 +576,10 @@ fetch_google_analytics_4_slow <- function(request_list,
     if(is.null(npt)){
       do_it <- FALSE
     }
+
+    if(as.integer(npt) >= max_rows){
+      do_it <- FALSE
+    }
     
     the_req$pageToken <- npt
     response_list <- c(response_list, out)
